py_stringsimjoin
================

This project seeks to build a Python software package that provides scalable implementation of string similarity joins over two tables, for commonly used similarity measures such as Jaccard, Dice, cosine, overlap, overlap coefficient and edit distance. The package is free, open-source, and BSD-licensed.

Important links
===============

 * Project Homepage: https://sites.google.com/site/anhaidgroup/projects/py_stringsimjoin
 * Code repository: https://github.com/anhaidgroup/py_stringsimjoin
 * Issue Tracker: https://github.com/anhaidgroup/py_stringsimjoin/issues
 * Mailing List: https://groups.google.com/forum/#!forum/py_stringsimjoin

Platforms
=========

py_stringsimjoin has been tested on Linux, OS X and Windows.
